import { Cluster } from 'aws-cdk-lib/aws-eks';
import { IManagedPolicy, Role } from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
export interface KarpenterProps {
    /**
     * The EKS Cluster to attach to
     */
    readonly cluster: Cluster;
    /**
     * The Kubernetes namespace to install to
     *
     * @default karpenter
     */
    readonly namespace?: string;
    /**
     * The helm chart version to install
     *
     * @default - latest
     */
    readonly version?: string;
    /**
     * Extra values to pass to the Karpenter Helm chart
     */
    readonly helmExtraValues?: any;
    /**
     * Custom NodeRole to pass for Karpenter Nodes
     */
    readonly nodeRole?: Role;
}
export declare class Karpenter extends Construct {
    readonly cluster: Cluster;
    readonly namespace: string;
    readonly version?: string;
    readonly nodeRole: Role;
    readonly helmExtraValues: any;
    private readonly chart;
    private readonly serviceAccount;
    constructor(scope: Construct, id: string, props: KarpenterProps);
    /**
     * compareVersion compare two Karpenter version, return true if the v1 is later one
     * parameter is relatively free form.
     *
     * @param v1 - first compared version
     * @param v2 - second compared version
     */
    private compareVersion;
    /**
     * addProvisioner adds a provisioner manifest to the cluster. Currently the provisioner spec
     * parameter is relatively free form.
     *
     * @param id - must consist of lower case alphanumeric characters, \'-\' or \'.\', and must start and end with an alphanumeric character
     * @param provisionerSpec - spec of Karpenters Provisioner object.
     */
    addProvisioner(id: string, provisionerSpec: Record<string, any>): void;
    /**
     * addNodeTemplate adds a node template manifest to the cluster. Currently the node template spec
     * parameter is relatively free form.
     *
     * @param id - must consist of lower case alphanumeric characters, \'-\' or \'.\', and must start and end with an alphanumeric character
     * @param nodeTemplateSpec - spec of Karpenters Node Template object.
     */
    addNodeTemplate(id: string, nodeTemplateSpec: Record<string, any>): void;
    /**
     * addManagedPolicyToKarpenterRole adds Managed Policies To Karpenter Role.
     *
     * @param managedPolicy - iam managed policy to add to the karpenter role.
     */
    addManagedPolicyToKarpenterRole(managedPolicy: IManagedPolicy): void;
}
